/*
 ============================================================================
 Name        : MainEta.c
 Author      : Jannes Nys
 Version     : v1.0 November 2016
 Copyright   : 
 Publication : unpublished + eta-MAID
 Description : Photoproduction of a pseudoscalar : gamma + N --> 0- + N'
               Applied to gamma + p --> eta + p
               To change the model, change 'CGLN_Ai'
               The model is based on Regge exchanges  + the MAID solution
 ============================================================================
 */



#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <complex.h>    	/* Standard Library of Complex Numbers */

#include "EtaPhotReggeModel.h"

int main(void) {
	// mass = { - , MGAMMA, MP, META, MP}
	double mass[5] = {0.0, 0.0, MP, META, MP};
	
	// read the input to plot
	double Eg;
	double t, cost;
        int ist;
        double vmin, vmax, dv;
        double dsigdt, photas, dsigdomega;
	
	// model parameters

	// open input files
	// plot range etc.
	FILE *plotinfile = fopen("plot_params.txt","r");
        fscanf(plotinfile,"%lf %d %lf %lf %lf\n", &Eg, &ist, &vmin, &vmax, &dv );
	fclose(plotinfile);


	// open output files
        FILE *plotoutfile = fopen("outputfile_etaphot_proton.txt","w");
        fprintf(plotoutfile, "# Beam energy Eg = %f GeV\n", Eg);
        fprintf(plotoutfile, "# Units: t (GeV^2),   cost (),   Dsig/Dt (micro barn/GeV^2),   Dsig/DOmega (micro barn) ,  Sigma ()\n");
        fprintf(plotoutfile, "#     t         cos        Dsig/Dt        Dsig/DOmega        Sigma  \n");

        // go to center of mass system
        double W = Eg2W(Eg);

        // calculate what the website needs
        if(ist == 1){
            // CHECK: if the tmin and tmax are outside [t1,t0]
            double t0 = Cos2T(W,+1.0,mass);
            double t1 = Cos2T(W,-1.0,mass);
            if (vmin < t1)
                vmin = t1;
            if (vmax > t0)
                vmax = t0;
        }
	for(double v = vmin; v <= vmax; v += dv){
                if(ist == 1){
                    // CHECK: if the tmin and tmax are outside [t1,t0]

                    t = v;
                    cost = T2Cos(W, t, mass);
                }else{
                    cost = v;
                    t = Cos2T(W, cost, mass);
                }

		// calculate observables
                dsigdt = EtaPhotCS_S(W, acos(cost));
                dsigdomega = dsigdt/Coef(W, mass);
                photas = EtaPhotBeamAs_S(W, acos(cost));
		
		// put them in a file
                fprintf(plotoutfile, "  %.5f     %.5f    %.10f    %.10f     %.6f\n", t, cost, dsigdt, dsigdomega, photas);
//                printf("t's : %lf \t %lf \t %lf\n",vmin, vmax, v);
	}

//        system("/opt/local/bin/gnuplot -p gnuplot.txt");
//        system("/usr/bin/gnuplot -p gnuplot.txt");


	return EXIT_SUCCESS;
}
